function gu = GUI
% Graphical User Interface for the Snow environment
%
% Starting the graphical user interface will clear the 
% workspace and close all windows. Then it will bring 
% up four windows for the analysis of flow and concentration
% fields around sinking spherical particles which leak 
% some substance. In these windows you can 
%
% . solve Navier Stokes equations for the flow
% . investigate properties of the flow field
% . specify the parameters for the substance transport
% . solve for the concentration of the substance
% . investigate properties of the concentration field
%
% You can also save the results of your work in files 
% on the hard disk, so you can investigate them later
% without solving the equations again.
% 
% To learn more about the environment, either start it up
% and click 'Help' in the various windows, or read the 
% accompanying white paper 'A Matlab Environment for 
% Analysis of Fluid Flow and Transport around a Translating
% Sphere' by Thygesen and Kirboe. You should have received
% this paper along with the software.

% Help for the developer:
%
% GUI - Constructor for the graphical user interface
%
persistent g

% Open the window which controls the computational grid
if isempty(g),
   
   g.StartWin = [];
   g.RootDir = pwd;
   g.Grid = [];
   g.Flow = [];
   g.Con = [];
   g.Post = [];
   

   g = class(g,'GUI');

   g.StartWin =  startupwin(g);
   if ~g.StartWin,
   	StartAction(g,'OK');
   end
end

if nargout == 1,
   gu = g;
end

return
