function AppendToFile(g,fname,opt)
%
% AppendToFile - save specifications of GUIcon object in a mat-file.
%
% AppendToFile(g,fname) will save information about Peclet numbers, methods, etc. and
% then call the AppendToFile method for the NumField in the GUIflow object.
%
% If an option is present as in AppendToFile(g,fid,opt), then opt is passed on
% to the AppendToFile method for the flow field.

if nargin==2,
	opt = [];   
end

if ~isfield(opt,'style')
   opt.style='mat';
end

Pe = Peclet(g);
TheBC = BC(g);
norma = Normal(g);
method = Method(g);

if strcmpi(opt.style,'mat')
   save(fname,'Pe','-append')
   save(fname,'TheBC','-append')
   save(fname,'norma','-append')
   save(fname,'method','-append')
end

if strcmpi(opt.style,'ascii')
   fprintf(fname,'##############################################################\n');
   fprintf(fname,'THE DIFFUSION EQUATION\n');
   fprintf(fname,'--------------------------------------------------------------\n');
   
   fprintf(fname,'Peclet  number:\t%6.2f\n',Pe);         
   fprintf(fname,strcat('Boundary condition: ',TheBC,'\n'));
   fprintf(fname,strcat('Normalisation: ',norma,'\n'));
   fprintf(fname,strcat('Method: ',method,'\n'));
   fprintf(fname,'--------------------------------------------------------------\n');
   

end

AppendToFile(NumField(g),fname,opt);

return