function g=GUIflowAction(g,action,option)

if nargin==2,
   option = [];
end

switch lower(action)
case 'refresh'
   g = GetFlow(g);
   g = GetReynold(g);
   g = GetCLVS(g);
   if ~isa(g.psi,'NumStreamFct'),
      g = ComputeFlow(g,option);
	   PlotFlow(g);   
   end
case 'style'
	PlotFlow(g);
case 'user'
   set(g.AutoHandle,'Value',0);
   set(g.UserCLevHandle,'backgroundcolor',0.95*[1 1 1]);
   g = GetCLVS(g);
   PlotFlow(g);   
case 'auto'
   if get(g.AutoHandle,'Value')
      set(g.UserCLevHandle,'backgroundcolor',0.5*[1 1 1])
   else
      set(g.UserCLevHandle,'backgroundcolor',0.95*[1 1 1])
   end
   
   g = GetCLVS(g);
   PlotFlow(g);
case 'object'
	PlotFlow(g);
case 'cbar'
   PlotFlow(g);
   Resize(g);
case 're'
   g.psi = reinit(g.psi);
   g = GetReynold(g);
   if ~isa(g.psi,'NumStreamFct'),
      g = ComputeFlow(g,option);
	   PlotFlow(g);   
   end
case 'stream'
   g = GetFlow(g);
   g.psi = reinit(g.psi);
   if ~isa(g.psi,'NumStreamFct'),
      set(g.SolveHandle,'Enable','off');
      g = ComputeFlow(g,option);
      PlotFlow(g);
   else
      set(g.SolveHandle,'Enable','on');
   end
case 'solve'
   g = ComputeFlow(g);
   PlotFlow(g);
case 'save'
   save(g);
case 'load'
   g = load(g);
case 'both'
   PlotFlow(g);
case 'getreynold'
   g = g.Reynold;
   
otherwise
   error(strcat('Unknown action in GUIflow: ',action));
end

return 

function p=GetFlow(p)
streamstring = p.PsiNames{get(p.StreamHandle,'Value')};
if strcmpi(streamstring,'numerical n-s solver'),
   p.psi = NumStreamFct;
else
   p.psi=streamfct(streamstring);
end
return

function p=GetReynold(p)
try
   dum = str2num(get(p.ReHandle,'String'));
   CheckScalar(dum,[0,Inf]);
   p.Reynold = dum;
catch
   asdf = lastline(lasterr);
   asdf = {'You entered an illegal parameter; the following error arose:','',...
         asdf,'','Press OK and re-edit the illegal parameter.'};
   menu(asdf,'OK');
end
return  

function p=GetCLVS(p)
p.AutoCLVS = get(p.AutoHandle,'Value');
if ~p.AutoCLVS,
   try
      dum = str2num(get(p.UserCLevHandle,'String'));
      CheckVector(dum);
      p.UserCLVS = dum;
   catch
      asdf = lastline(lasterr);
      asdf = {'You entered an illegal parameter; the following error arose:','',...
            asdf,'','Press OK and re-edit the illegal parameter.'};
      menu(asdf,'OK');
   end
end
return

function p = ComputeFlow(p,option)
	%%%%%%%%%%%%%% Compute flow field %%%%%%%%%%%
	if nargin==1,
   	option = [];
	end

	cg = compgrid(GUIgrid);

   setptr(p.FigHandle,'watch')
   
   if isa(p.psi,'NumStreamFct'),
      p.psi = Set_Re(p.psi,p.Reynold);
      p.psi = Set_grid(p.psi,cg);
      p.psi = Solve(p.psi);
      p.FlowField = flowfield(p.psi);
      p.StreamFunctionField = NumField(p.psi);
   else % The the chosen stream function is analytical
      p.FlowField = flowfield(p.psi,cg,p.Reynold);   
      NumPsi = p.psi(RR(cg),TT(cg),p.Reynold);
      p.StreamFunctionField = NumField(NumPsi,cg,'Stream Function',1);      
   end
   
   setptr(p.FigHandle,'arrow')
   Hide(GUIcon);
return

function PlotFlow(p)
   setptr(p.FigHandle,'watch')
   
	figure(p.FigHandle)
   
   % Delete the colorbar, if present
   if get(p.CbarHandle,'value'),
      delete(findobj(get(p.FigHandle,'children'),'tag','FlowColorBar'));
   end
   
   cla
   % Take care of plot options from checkboxes etc.
   
   if get(p.BothHandle,'value')
      plotoptions.size = 'full';
   else
      plotoptions.size = 'half';
   end
   
   if ~p.AutoCLVS,
      plotoptions.CLVS = p.UserCLVS;
   end
   
   stylestrings=get(p.StyleHandle,'string');
   plotoptions.style=stylestrings{get(p.StyleHandle,'value')};
   
   objectstrings=get(p.ObjectHandle,'string');
   plotoptions.object=objectstrings{get(p.ObjectHandle,'value')};
     
   if strcmpi(plotoptions.object,'Stream function'),
      plot(p.StreamFunctionField,plotoptions);
   elseif strcmpi(plotoptions.object,'Coagulation Kernel')
      R = RR(compgrid(p));
      R = R(:,1);
      plot(R,CoagKernel(p.psi,R))
   else
      plot(p.FlowField,plotoptions)
   end
   
%	set(gca,'position',p.AxesPos);
   
	if get(p.CbarHandle,'value'),
      hcb = colorbar;
      set(hcb,'tag','FlowColorBar');
   end
   
   setptr(p.FigHandle,'arrow')
return
   