function AppendToFile(g,arg1)
%
% Appends the GUIpost object, and all previous objects, to a file.
%

if ~nargin==2,
   error('AppendToFile should be called as ''AppendToFile(GUIpost,str)'' ')
end

switch lower(arg1)
case 'save'
   FileKey = '*.mat';
   Header = 'Save as';
case 'print'
   FileKey = '*.txt';
   Header = 'Print as';
otherwise 
   error('Unknown action in AppendToFile')
end

%%%% If possible, temporarily shift to the Userdata subdirectory ...
GoBack = 1;
try
   cd(GetRootDir(GUI));
   cd Userdata
catch
   GoBack = 0;
end

[fname,fpath] = uiputfile(FileKey,Header);

if GoBack
   cd ..
end

% May be called as GUIpost('save') in which case all data is to be saved ...
if strcmpi(arg1,'save'),
   
   %%%% fname is false if the user pressed cancel
   if fname,
      DateOfRun = date;
      TimeOfRun = clock;
      
      fname = strcat(fpath,fname);
      save(fname,'DateOfRun')
      save(fname,'TimeOfRun','-append')
      
      opt.style = 'mat';
      
      AppendToFile(GUIgrid,fname,opt);
      AppendToFile(GUIflow,fname,opt);
      AppendToFile(GUIcon,fname,opt);
      
      Thresh = Threshold(g);
      DenseArea = Area(g);
      DenseDiameter = Diameter(g);
      TotalFlow = Flow(g);
      
      save(fname,'Thresh','DenseArea','DenseDiameter','-append')
      save(fname,'TotalFlow','-append')
   end
   
   return   
end

if strcmpi(arg1,'print'),
   if fname,
      % Open text file for rewriting
      fname = strcat(fpath,fname);
      [fid,mess] = fopen(fname,'wt');
      
      % Repeat until we have succesfully opened a file for writing
      % or pressed 'Cancel'.
      while fid==-1,
         errordlg({'Error on opening the file for writing.',...
               'The operating system returned the following',...
               'error message:',...
               '',...
               mess,...
               '',...
               'Maybe the file is used by another program?',...
               'Choose another file or press Cancel.',...
               'Then close this window.',...
            },'File error','replace');
         cd Userdata
         [fname,fpath] = uiputfile('*.txt','Print As');
         cd ..
         
         if fname,
            % Open text file for rewriting
            fname = strcat(fpath,fname);
            [fid,mess] = fopen(fname,'wt');
         else
            return
         end
      end
      
      % What to write 
      opt.style = 'ascii';
      DateOfRun = date;
      TimeOfRun = clock;
      
      % Write it ...
      fprintf(fid,'##############################################################\n');
      fprintf(fid,'Output from PLANKTON computations\n');
      fprintf(fid,'--------------------------------------------------------------\n');
      fprintf(fid,strcat('Date of run: ',DateOfRun,'\n'));
      fprintf(fid,strcat('Time of run: ',int2str(TimeOfRun(4)),int2str(TimeOfRun(5)),'\n'));
      fprintf(fid,'--------------------------------------------------------------\n');
      AppendToFile(GUIgrid,fid,opt);
      AppendToFile(GUIflow,fid,opt);
      AppendToFile(GUIcon,fid,opt);
      fprintf(fid,'##############################################################\n');
      fprintf(fid,'POSTPROCESSING INFORMATION\n');
      fprintf(fid,'--------------------------------------------------------------\n');
      fprintf(fid,'Threshold concentration     :\t%6.2f\n',Threshold(g));
      fprintf(fid,'Area with high concentration:\t%6.2f\n',Area(g));
      fprintf(fid,'Diameter of concentration   :\t%6.2f\n',Diameter(g));
      fprintf(fid,'Flow away from sphere       :\t%6.2f\n',Flow(g));
      fprintf(fid,'##############################################################\n');
      fprintf(fid,'#######################   end of file   ######################\n');
      fprintf(fid,'##############################################################\n');
      fclose(fid);
   end
   
   return
end

return
