function g = GUIpost
% This window post-processes the solution of the PDE.
% 
% You can explore the set where the concentration is greater
% than a given threshold concentration you choose.
% The diameter of the set is two times the largest x in this set.
% The area is in the x-z plane (The sphere itself is not counted here)
% Finally, the total solute flow away from the sphere is computed.
% 
% Press Save to have all data from this computation saved in a
% mat-file for further processing. Press Print to have a subset of
% the data saved in an ascii-file.

% DUCOMENTATION FOR THE DEVELOPER  
%
% GUIpost - constructor for the GUI post object
%
% Syntax: g = GUIpost
%
% IF no GUIpost object exists, then one is constructed when this
% function is called.
%
% At most one GUIpost object can live at once.
%
% The GUIpost object is returned in g. 

persistent TheGUIpost

if isempty(TheGUIpost),
   TheGUIpost = 1; %Hack to avoid recursion
   g.FigHandle = GUIpostFig;
   g.DiamHandle = findobj(g.FigHandle,'tag','PostDiam');
   g.AreaHandle = findobj(g.FigHandle,'tag','PostArea');
   g.FlowHandle = findobj(g.FigHandle,'tag','PostFlow');
   g.VolHandle  = findobj(g.FigHandle,'tag','PostVolume');

   TheGUIpost = class(g,'GUIpost');
end

if nargout ==1,
   g = TheGUIpost;
end

return

function fig = GUIpostFig()
% Lay-out parameters

% x coor of the 3 columns
labelx = 1;
editx = 18;
butx = 29;

% Dimensions of controls
labeldim = [15 1.5];
editdim = [10 1.5];
butdim = [7 1.5];

ydiff = 1.1;
my = 5;

% 
butpos = [butx,7.2;butx,3.9;butx,0.6];


h0 = figure('Color',[0.8 0.8 0.8], ...
   'Name','Post Processing',...
   'units','character',...
	'Position',[88 3  37 12], ...
   'PaperPositionMode','auto',...
   'Resize','off',...
   'MenuBar','none',...
	'Tag','PostFig');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[labelx my+2*ydiff labeldim], ...
	'String','Threshold', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'callback','Refresh(GUIpost)',...   
	'BackgroundColor',[1 1 1], ...
	'ListboxTop',0, ...
   'Position',[editx my+2*ydiff editdim], ...
   'String','0.5',...
	'Style','edit', ...
	'Tag','PostThreshold');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[labelx my labeldim], ...
	'String','Plume diam.', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[labelx my-ydiff labeldim], ...
	'String','Plume area', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[labelx my-2*ydiff labeldim], ...
	'String','Plume Volume', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[editx my editdim], ...
	'Style','text', ...
	'Tag','PostDiam');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[editx my-ydiff editdim], ...
	'Style','text', ...
	'Tag','PostArea');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[editx my-2*ydiff editdim], ...
	'Style','text', ...
	'Tag','PostVolume');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'Callback','AppendToFile(GUIpost,''save'')', ...
	'ListboxTop',0, ...
	'Position',[butpos(1,:) butdim], ...
	'String','Save');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'Callback','AppendToFile(GUIpost,''print'')', ...
	'ListboxTop',0, ...
	'Position',[butpos(2,:) butdim], ...
	'String','Print');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'Callback','helpwin(''GUIpost'')', ...
	'ListboxTop',0, ...
	'Position',[butpos(3,:) butdim], ...
	'String','Help');
DefFontSize = get(h1,'fontsize');
h1 = uicontrol('Parent',h0, ...
	'FontSize',DefFontSize+2, ...
	'Units','char', ...
	'FontWeight','demi', ...
	'ListboxTop',0, ...
	'Position',[labelx my+4*ydiff 35 2], ...
	'String','Post-processing', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[editx my-4*ydiff editdim], ...
	'Style','text', ...
	'Tag','PostFlow');
h1 = uicontrol('Parent',h0, ...
	'Units','char', ...
	'ListboxTop',0, ...
	'Position',[labelx my-4*ydiff labeldim], ...
	'String','Net solute flow', ...
	'Style','text', ...
	'Tag','StaticText2');
if nargout > 0, fig = h0; end
