function AppendToFile(nf,fname,opt)
%l
% AppendToFile - save specifications of NumField in a mat-file.
%
% AppendToFile(nf,fname) will append matrix C to the 
% mat-file fname.
%
% AppendToFile(nf,fname,opt) with opt.style=='ascii' will print 
% matrix C to the ascii-file with file id fname. (See also fprintf).

C = Val(nf);
R = RR(nf);

if nargin==2,
	opt = [];   
end

if ~isfield(opt,'style')
   opt.style='mat';
end

if strcmpi(opt.style,'mat')   
   save(fname,'C','-append')
   return
end

if strcmpi(opt.style,'ascii')
   M = size(R,1);
   dM = max(1,round(M/10));
   
   fprintf(fname,'##############################################################\n');
   fprintf(fname,'THE CONCENTRATION FIELD\n');
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Upstream\n');
   fprintf(fname,'Radius\tConcentration\n');
   for i=1:dM:M
   	fprintf(fname,'%6.2f\t%6.2f\n',R(i,end),C(i,end));
   end
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Downstream\n');
   fprintf(fname,'Radius\tConcentration\n');
   for i=1:dM:M
   	fprintf(fname,'%6.2f\t%6.2f\n',R(i,1),C(i,1));
   end
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Off equator\n');
   fprintf(fname,'Radius\tConcentration\n');
   j=round((1+size(R,2))/2);
   for i=1:dM:M
   	fprintf(fname,'%6.2f\t%6.2f\n',R(i,j),C(i,j));
   end
   fprintf(fname,'##############################################################\n');
   return
end

error('Error in AppendToFile: Unrecognized style field in option')
