function a = DenseDiameter(NF,t)
%
% DenseArea - compute diameter of high concentration 
%
% Syntax: a = DenseDiameter(NF,t)
%
% will return 2 times the largest x for which the concentration is 
% greater than the threshold t.
%
% See also: NumField.
%

C = Val(NF);
X = XX(NF);
T = TT(NF);
R = RR(NF);
T = TT(NF);

% If maximum value of C is less than t, then there is not much to compute.
if max(C(:))<t,
   a = 0;
   return
end

% abs(X).*( C >= t) returns the abs(X) coordinates of points in the set we're 
% after. Take max over all radia
[mx,ir] = max(abs(X).*(C >= t ));

% Take max over angle
[a,it] = max(mx);
ir = ir(it);

[M,N] = size(C);

% If possible, include a first order correction term
if it<N & ir<M,
   dCdr = ( C(ir+1,it) - C(ir,it) ) / (R(ir+1,it) - R(ir,it));
   dCdt = ( C(ir,it+1) - C(ir,it) ) / (T(ir,it+1) - T(ir,it));
   
   dCdx = dCdr*sin(T(ir,it)) + dCdt * cos(T(ir,it)) / R(ir,it);
   
   % You may use this to verify that we are at the right point:
   %   dCdz = dCdr*cos(T(ir,it)) - dCdt * sin(T(ir,it)) / R(ir,it);
   % .... should be (close to) zero.

	da = - (C(ir,it) - t) / dCdx;
   
   a = a + da;
end

% Multiply by two to get diameter in stead of radius
a = 2*a;

return
