function [theta,Sh] = LocalSherwood(nf)
%
% [theta,Sh] = LocalSherwood(nf)
%
% returns the local Sherwwod number along the surface of the sphere.
%
%   Sh(theta) = - (dC/dr) / C  
%
% where the concentration and its radial derivative are evaluated at
% (r=1,theta)

lg = compgrid(nf);

theta = TT(lg);
theta = theta(1,:);

R = RR(lg);
R = R(5);

lg = refine(lg,1,R);

C = Val(nf);
C = C(1:size(lg,1),:);

D = FourthOrderCentral(lg);

dCdr = D.dr * C;

Sh = - dCdr(1,:) ./ C(1,:);

theta = theta';
Sh = Sh';
