function NF=NumField(C,cg,name,ZeroPole)
%
% NumField - numerical representation of a scalar field
%
% Constructor:
%
%    NF = NumField(C,cg,name,ZeroPole)
%
% where cg is a compgrid and C is a matrix of values corresponding
% to cg. name, which can be omitted, attaches a name to the field. If
% ZeroPole is present and non-zero, then it is assumed that the field 
% has value 0 at the poles.
%
% Derived from : Compgrid, scalarfield

if nargin<4,
   ZeroPole = 0;
end

if nargin<3,
   name = 'Unnamed numerical field';
end

if nargin<2,
   cg = compgrid;
end

if nargin<1,
   C = zeros(size(cg));
end

if any(size(C)~=size(cg)),
   error('In NumField, the value matrix must have same dimensions as the grid.')
end

s = scalarfield(name);

NF.C = C;
NF.ZeroPole = ZeroPole;

NF = class(NF,'NumField',cg,s);
