function RF = continuation(NF,cg,q,Peclet,Gamma)

if Gamma<1,
   error('Continuation requires Gamma=1 (because we need analytical solutions)')
end

[X,Z] = XZ(cg);

X1 = X(1,:);
Z1 = Z(1,:);

[t,r] = cart2pol(Z1,X1);
C1 = max(0,interp(NF,r,t));

options.Peclet = Peclet;
options.Gamma = Gamma;

% The Csanady analytical solution
csafunstr = 'Pe*q/4/pi./sqrt(x.^2+(z-z0).^2).*exp(-0.5*Pe*(sqrt(x.^2+(z-z0).^2)-(z-z0)))';

csa = inline(csafunstr,'x','z','Pe','q','z0');

% Loss function 
LF = inline(strcat('sum((C-(',csafunstr,')).^2)'),'z0','C','x','z','Pe','q');

Z0 = fmin(LF,-30,30,[],C1,X1,Z1,Peclet,q);

RF = CylField(csa(X,Z,Peclet,q,Z0),cg);

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This stuff has to do with solving the PDE numerically on the cylindrical 
% grid and belongs to an earlier version ...
%%%%%%%%%%%%%%%%%%%%%%%%%%%

[t,r] = cart2pol(Z1,X1)
options.C0 = max(0,interp(NF,r,t));

[t,r] = cart2pol(Z(2,:),X(2,:));
options.C1 = max(0,interp(NF,r,t));

[t,r] = cart2pol(Z(:,end),X(:,end));
options.Cout = max(0,interp(NF,r,t));

[t,r] = cart2pol(Z(:,end-1),X(:,end-1));
options.Cout1 = max(0,interp(NF,r,t));

TM = TensorMatrix(cg,options);

RF = CylField(SolveEquation(TM),cg);
