function dc=Diff(nf,options)
%
% Diff - numerical differentiation of NumField.
%
%   dc=Diff(c,options)
% 
% Computes a numerical approximation to dc/dr and dc/dt.
% Both dc.dt and dc.dr are matrices of same size as e.g. RR(nf).

if nargin<4,
   options.opt = 0;
end

if ~isfield(options,'order')
   options.order = 4;
end

% Do the math

C = Val(nf);

if options.order==2,
   D = SecondOrderCentral(nf);
end

if options.order==4,
   D = FourthOrderCentral(nf);
end

if ~exist('D')
   error('Unrecognized order.');
end

dc.dt = D.dth * C;
dc.dr = D.dr * C;
return   
