function C1 = interp(nf,R1,T1,options)
%
% C1 = interp(nf,R1,T1)
%
% Interpolates the numerical field nf at values R1,T1. The result is a matrix
% of same size as R1 and T1.
%
% Arguments in R1 which are outside the support of the numerical field
% are projected onto the boundary.
%
% Arguments in T1 which are outside [0,pi] are projected onto that interval.

if nargin<4,
   options = [];
end

m = 'spline';

if isa(options,'char')
   m = options;
end

if isfield(options,'method'),
   m = options.method;
end

C = Val(nf);
R = RR(nf);
T = TT(nf);

R = [R(:,1),R,R(:,end)];
T = [-T(:,1),T,2*pi-T(:,end)];

if nf.ZeroPole,
	C = [-C(:,1),C,-C(:,end)];   
else
	C = [C(:,1),C,C(:,end)];   
end

T2 = min(T1,pi);
T2 = max(T2,0);

R2 = min(R1,max(R(:)));
R2 = max(R2,min(R(:)));

C1 = interp2(T,R,C,T2,R2,m);
