function psi=NumStreamFct(options)
%
% psi=NumStreamFct(options)
%
% Constructor for a NumSteramFct object.
%
% In included, options must be a structure. The following fields are recognised:
%
%   Re.         The Reynolds number. Default: 1
%   cg.         The computational grid. Default: compgrid;
%   init.       The initial guess on the streamfunction. Default: streamfct('stokes')
%   tolerance.  When both the change in velocity at the surface of the sphere,
%               and the change in the streamfunction, is below this level, the 
%               iteration stops.
%   maxit.      If this number of iteration has been done without convergence being
%               reached, the iteration stops at 
if nargin<1,
   options = [];
end

if isfield(options,'Re')
   Re = options.Re;
else
   Re = 1;
end

if isfield(options,'cg')
   cg = options.cg;
else
   cg = compgrid;
end

if isfield(options,'tolerance')
   psi.tolerance = options.tolerance;
else
   psi.tolerance = 1e-4;
end

if isfield(options,'maxit')
   psi.maxit = options.maxit;
else
   psi.maxit = 200;
end


sf = scalarfield('Numerically solved stream function');
psi.Updated = 0;
psi.startiter = 0;
psi.Re = Re;
psi.cg = cg;

psi.vor = [];
psi.val = [];
psi.ur = [];
psi.ut = [];

psi = class(psi,'NumStreamFct',sf);
