function [psi,ur,ut,vor] = nnss_Chang(Re,gr,options)

dt = 0.005;
tfinal = 1;

D = FourthOrderCentral(gr);
[M,N] = size(gr);

R = RR(gr);
T = TT(gr);
sT = sin(T);
cT = cos(T);

D2r = D.dr2 + 2*R*D.dr;
D2t = sT.^2* D.dt2 + sT.*cT* D.dt - eye(D2r);
A = 1./sT.^2 * D2t;

VorOp = D2r - R.^2*Re/dt + A;
cop = D2r + D2r + A;


for t = 0:dt:tfinal,
   Rt = zeros(M,N);
   
      
end



stokes = streamfct('stokes');

sTR = XX(gr);
sTR2 = sTR.*R;
cotT = cot(T);
cT = cos(T);

[M,N] = size(gr);

% Get differential operators
[D2,Dr,Dt] = DiffOps(gr);

% Get initial stokes velocities and stream function
[ur,ut] = PolarVel(stokes,R,T,Re);
po.style = 'surf';

C = stokes(R,T,Re)./sTR;

vor = -(D2*C);

urold = ur;
utold = ut;
vorold = vor;
Cold = C;

A = SparseTensor(2*M,N);
B = sparse([],[],[],2*M,N,4*N);

A(1:M,1:N,1:M,1:N) = D2;
A(1:M,1:N,M+(1:M),1:N) = eye(D2);
A(M+(1:M),1:N,M+(1:M),1:N) = D2;

% Boundary conditions
for j=1:N,
   % C at outer boundary
   A(M,j,:,:)=sparse(M,j,1,2*M,N,1);
   % C at inner boiundary
   A(1,j,:,:)=sparse(1,j,1,2*M,N,1);
   % vor at outer boundary
   A(2*M,j,:,:)=sparse(2*M,j,1,2*M,N,1);
   % vor at the inner boundary
   A(M+1,j,:,:)=sparse(M+1,j,1,2*M,N,1);
end
warning('Here the vorticity at the boundaries is taken for granted.')

% Free flow at the outer boundary
B(M,:) = 0.5 * sTR(M,:);
% Vorticity at the inner boundary
B(M+1,:) = sqrt(2) * sT(1,:);
warning('This is a nonsense inner vorticity.')

toc
tic

C = A\B;
toc

vor = C(M+(1:M),:);
C = C(1:M,:);
psi = C .* sTR;
[ur,ut] = PsiToU(psi,Dr,Dt);

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [D2,Dr,Dt] = DiffOps(gr)
global R T sT sTR sTR2 cotT cT


A = SparseTensor(M,N);
B = sparse([],[],[],M,N,2*N);

L = (2./R)*D.dr + D.dr2 + (cotT./R.^2)*D.dth + (1./R.^2)*D.dth2;

% This is the D2-operator of Chang and Maxey
D2 = L - (1./sTR2)*eye(L);

Dr = D.dr;
Dt = D.dth;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ur,ut] = PsiToU(psi,Dr,Dt)
global R T sT sTR sTR2 cotT cT

ur=   (Dt*psi) ./sTR2;

ut= - (Dr*psi) ./sTR;
