function [psi,ur,ut,vor] = nnss_psi(Re,cg,options)
global psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT gr D2modDirs

maxit = 20;
tol = 1e-4;

gr = cg;

stokes = streamfct('stokes');

R = RR(gr);
T = TT(gr);
sT = sin(T);
sTR = XX(gr);
sTR2 = sTR.*R;
cotT = cot(T);
cT = cos(T);

% Get differential operators
DiffOps;

% Get initial stokes velocities and stream function
[ur,ut] = PolarVel(stokes,R,T,Re);
po.style = 'surf';

psi = stokes(R,T,Re);

D2psi = (D2*psi);

%urold = ur;
%utold = ut;
%D2psiold = D2psi;

nit = 0;
while 1
   psiold = psi;
   nit = nit + 1
   SolveD2psi(Re);
	SolvePsi;
	PsiToU;
   
   if norm(psiold-psi,1) < tol,
      break
   end
   
   if nit > maxit,
      warning('Maximum number of iterations exceeded. Psi changed to -psi.')
      psi = -psi;
      break
   end
end
disp(['Number of iterations: ',int2str(nit)])

PsiToVor;

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function DiffOps
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT D2modDir

D = SecondOrderCentral(gr);
[M,N] = size(gr);

A = SparseTensor(M,N);
B = sparse([],[],[],M,N,2*N);

D2 = D.dr2 + 1./R.^2*D.dth2 - cotT./R.^2 * D.dth;

% D2 operator modified for Dirichlett boundary conditions
D2modDir = D2;

for j=1:N,
   D2modDir(M,j,:,:)=sparse(M,j,1,M,N,1);
   D2modDir(1,j,:,:)=sparse(1,j,1,M,N,1);
end

for i=1:M,
   D2modDir(i,1,:,:)=sparse(i,1,1,M,N,1);
   D2modDir(i,N,:,:)=sparse(i,N,1,M,N,1);
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function SolveD2psi(Re)
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT
persistent A
% Differential operator 
A = D2 - Re./sTR2*((D.dth*psi)*D.dr - (D.dr*psi) * D.dth + ( 2* cotT.* (D.dr*psi) - 2*(D.dth*psi)./R) * eye(D.dr));

[M,N] = size(R);

% Set up differential operators for Dirichlet type conditions 
% at inner and outer boundary
   
for j=1:N,
   A(M,j,:,:)=sparse(M,j,1,M,N,1);
   A(1,j,:,:)=sparse(1,j,1,M,N,1);
end

for i=1:M,
   A(i,1,:,:)=sparse(i,1,1,M,N,1);
   A(i,N,:,:)=sparse(i,N,1,M,N,1);
end

% Right hand side
B = sparse([],[],[],M,N,2*N);

% At outer boundaries (free flow) D2psi is 0 ....  B(M,:) = zeros(1,N);
% At the fore-and-aft boundary I think D2psi is zero as well
% warning('Is this the right boundary condition for D2psi at theta = 0,pi?')

% At the inner boundary we take the Stokes solution ...
%B(1,:) = 3/2*sT(1,:).^2;
% .. or the Proudman-Pearson Inner solution 
B(1,:) = 0.5*sT(1,:).^2.*(3 + Re*(9/8 - 1.5*cT(1,:)));
% warning('I changed the 0.25*sin ... back to 0.5*sin')

% disp('Solution of vorticity equation')
D2psi = A\B;

return
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function SolvePsi
global D2modDir gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT D2modDir

%disp('Solution of psi equation')
[M,N] = size(psi);

BC = D2psi;
BC([1,M],:) = psi([1,M],:);
BC(:,[1,N]) = 0*psi(:,[1,N]);
psi = D2modDir\BC;

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PsiToU
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT

ur=   (D.dth*psi) ./sTR2;
ut= - (D.dr*psi) ./sTR;
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PsiToVor
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT

vor  = ( ut + D.dr*ut - D.dth * ur ) ./ R;
return 

% Laplace operator in spherical coor's
%L = (2./R)*D.dr + D.dr2 + (cotT./R.^2)*D.dth + (1./R.^2)*D.dth2;
%D2chang = L - 1./sTR.^2*eye(L);
% warning('The computation of the vorticity at the boundaries fails because psi./sTR is odd.')
%vor = - D2chang*(psi./sTR);
%return
