function [psi,ur,ut,vor] = nnss_newton(Re,cg,options)
global psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT gr 

maxit = 20;
tol = 1e-4;

gr = cg;

stokes = streamfct('stokes');

R = RR(gr);
T = TT(gr);
sT = sin(T);
sTR = XX(gr);
sTR2 = sTR.*R;
cotT = cot(T);
cT = cos(T);

[M,N] = size(R);

% Get differential operators
DiffOps;

% Get initial stokes velocities and stream function
[ur,ut] = PolarVel(stokes,R,T,Re);
po.style = 'surf';

psi = stokes(R,T,Re);
pfo = psi(end,:);

D2psi = (D2*psi);

x = [psi;D2psi];
x=x(:);
for i=1:10,
   A = nsgradfun(x,D2,pfo,Re,D,sTR2,cotT,R);
   condest(A)
	x = x - A\errfun(x,D2,pfo,Re,D,sTR2,cotT,R);
end

%x = errfun(x,D2,pfo,Re,D,sTR2,cotT,R);
x = reshape(x,2*M,N);


%[x,opt] = fsolve('errfun',x0,[],'nsgradfun',D2,pfo,Re,D,sTR2,cotT,R);
%format long
%opt
%format short

psi = x(1:M,:);
D2psi = x(M+(1:M),:);

PsiToVor;

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function DiffOps
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT D2modDir

D = SecondOrderCentral(gr);
[M,N] = size(gr);

A = SparseTensor(M,N);
B = sparse([],[],[],M,N,2*N);

D2 = D.dr2 + 1./R.^2*D.dth2 - cotT./R.^2 * D.dth;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PsiToU
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT

ur=   (D.dth*psi) ./sTR2;
ut= - (D.dr*psi) ./sTR;
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PsiToVor
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT

vor  = ( ut + D.dr*ut - D.dth * ur ) ./ R;
return 

