function [psi,ur,ut,vor] = nnss_chang(Re,cg,options)
global psi ur ut D2psi vor Ds D2s D D2 R T sT sTR sTR2 cotT cT gr D2modDirs nit par

par.method = 1;
par.tol = 1e-4;
par.maxit = 100;

maxit = 500;
tol = 1e-4;

gr = cg;

stokes = streamfct('stokes');

R = RR(gr);
T = TT(gr);
sT = sin(T);
sTR = XX(gr);
sTR2 = sTR.*R;
cotT = cot(T);
cT = cos(T);

% Get initial stokes velocities and stream function
[ur,ut] = PolarVel(stokes,R,T,Re);
po.style = 'surf';

psi = stokes(R,T,Re);

% Get differential operators
DiffOps;
D2psi = (D2*psi);

nit = 0;
while 1
   nit = nit + 1
   
   psiold = psi;
   SolveD2psi(Re);
	SolvePsi;
   PsiToU;
   
   disp ([max(max(abs(ut(1,:)))), norm(psiold-psi,1)])
   if max(max(abs(ut(1,:)))) < tol & norm(psiold-psi,1) < tol,
      break
   end
   
   if nit > maxit,
      warning('Maximum number of iterations exceeded. Psi changed to -psi.')
      psi = -psi;
      break
   end
end
disp(['Number of iterations: ',int2str(nit)])

PsiToVor;

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function DiffOps
global gr psi ur ut vor D Ds D2s R T sT sTR sTR2 cotT cT D2modDir

% D = FourthOrderUpwind(flowfield(ur,ut,gr),1);
D = SecondOrderCentral(gr);
[M,N] = size(gr);

% D2A = D.dr2A + 1./R.^2*D.dth2A - cotT./R.^2 * D.dthA;
% D2B = D.dr2B + 1./R.^2*D.dth2B - cotT./R.^2 * D.dthB;
% D2 = 0.5*(D2A + D2B);

D2 = D.dr2 + 1./R.^2*D.dth2 - cotT./R.^2 * D.dth;

% D2 operator modified for Dirichlett boundary conditions
D2modDir = D2;

% Inner and outer boundaries
D2modDir = SetUnity(D2modDir,ones(1,N),1:N);
D2modDir = SetUnity(D2modDir,M*ones(1,N),1:N);

% Center line boundaries
%D2modDir = SetUnity(D2modDir,1:M,ones(1,M));
%D2modDir = SetUnity(D2modDir,1:M,N*ones(1,M));

Ds = SecondOrderCentral(gr,-1);
D2s = Ds.dr2 + 1./R.^2*Ds.dth2 - cotT./R.^2 * Ds.dth;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function SolveD2psi(Re)
global gr psi ur ut D2psi vor Ds D2s R T sT sTR sTR2 cotT cT nit par
persistent A qB dB qu a
% Differential operator 
A = D2s - Re./sTR2*((Ds.dth*psi)*Ds.dr - ...
   (Ds.dr*psi) * Ds.dth + ( 2* cotT.* (Ds.dr*psi) - 2*(Ds.dth*psi)./R) * eye(Ds.dr));

[M,N] = size(R);

% Set up differential operators for Dirichlet type conditions 
% at inner and outer boundary
A = SetUnity(A,ones(1,N),1:N);
A = SetUnity(A,M*ones(1,N),1:N);

% Ditto for center line boundaries 
%A = SetUnity(A,1:M,ones(1,M));
%A = SetUnity(A,1:M,N*ones(1,M));

% Right hand side
B = sparse([],[],[],M,N,2*N);

% At outer boundaries (free flow) D2psi is 0 ....  B(M,:) = zeros(1,N);
% At the fore-and-aft boundary I think D2psi is zero as well
% warning('Is this the right boundary condition for D2psi at theta = 0,pi?')

if nit<2,
   % First iteration:
   % At the inner boundary we take the Stokes solution ...
   B(1,:) = 3/2*sT(1,:).^2;
   % .. or the Proudman-Pearson Inner solution 
   % B(1,:) = 0.5*sT(1,:).^2.*(3 + Re*(9/8 - 1.5*cT(1,:)));
   qB = zeros(size(B(1,:)));
else
   if nit>2,
      % estimate the parameter a
      du = ut(1,:) - qu;
      anew = dB*du' / (dB*dB');
      a = (1 - 1/nit) * a + 1/nit * anew
      k = -1/a
   else
      k = - 1;
      a = 1;
   end
   
   B(1,:) = qB + k*ut(1,:);
end

% Save boundary condition for next iteration
dB = B(1,:) - qB;
qB = B(1,:);
qu = ut(1,:);

% disp('Solution of vorticity equation')
% par.init = D2psi;
D2psi = mldivide(A,B); % ,par);

return
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function SolvePsi
global D2modDir gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT D2modDir nit par

%disp('Solution of psi equation')
[M,N] = size(psi);

BC = D2psi;
BC([1,M],:) = psi([1,M],:);
% BC(:,[1,N]) = psi(:,[1,N]);

par.init = psi;
psi = mldivide(D2modDir,BC,par);

return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PsiToU
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT

ur=   (D.dth*psi) ./sTR2;
ut= - (D.dr*psi) ./sTR;
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function PsiToVor
global gr psi ur ut D2psi vor D D2 R T sT sTR sTR2 cotT cT

vor  = ( ut + D.dr*ut - D.dth * ur ) ./ R;
return 

% Laplace operator in spherical coor's
%L = (2./R)*D.dr + D.dr2 + (cotT./R.^2)*D.dth + (1./R.^2)*D.dth2;
%D2chang = L - 1./sTR.^2*eye(L);
% warning('The computation of the vorticity at the boundaries fails because psi./sTR is odd.')
%vor = - D2chang*(psi./sTR);
%return
