function T = SparseTensor(M,N,nmax,mat)
% SparseTensor - constructor for the SparseTensor class
%
% Syntax:
%
%    T = SparseTensor(M,N,nmax)
%
% generates a SparseTensor object representing a sparse
% M-by-N-by-M-by-N array with initial memory allocated 
% for nmax non-zero elements. If nmax is omitted then it
% is set to 0.
%
% Try also 'methods SparseTensor'.

if nargin<3,
   nmax = 0;
end

if nargin<4,
   T.mat = sparse([],[],[],M*N,M*N,nmax);
	else
   if any(size(mat)~=[M*N,M*N]),
      error('Wrong dimensions of initial sparsetensor. Must be M*N-by-M*N')
   end   
   T.mat = sparse(mat);
end

T.M = M;
T.N = N;

T = class(T,'SparseTensor');
