function C = mtimes(A,B)
%
% mtimes - Products involving a SparseTensor
%
% Allowed combinations:
% 
%   A is an M-by-N-by-M-by-N SparseTensor
%   B is a  M-by-N matrix
%   c is a scalar
%
%   D=A*c  or D=c*A corresponds to D_ijkl = c A_ijkl
%
%   D=A*B           corresponds to D_ij = sum_kl A_ijkl B_kl
%                   (in Einstein notation: D_ij = A_ijkl B_kl)
%
%   D=B*A           corresponds to D_ijkl = B_ij * A_ijkl
%

dA = size(A);
dB = size(B);

if length(dB)==2,
	if all(dB==[1,1]),
   	A.mat = B*A.mat;
	   C = A;
   	return
   else
      M=dA(1);
      N=dA(2);
      if all(dB==[M,N]),
         C = reshape(A.mat*reshape(B,N*M,1),M,N);
         return
      end
   end
end

if length(dA)==2,
	if all(dA==[1,1]),
   	B.mat = A*B.mat;
	   C = B;
   	return
   else
      M=dA(1);
      N=dA(2);
      if all(dA==[M,N]),
         B.mat = spdiags(reshape(A,M*N,1),0,M*N,M*N)*B.mat;
         C = B;
         return
      end
   end
end

disp('In product involving a SparseTensor, I don''t know what to mutliply.')
error('Try help SparseTensor/mtimes')