function a=subsref(T,S,B)
%
% Subsref function. Implements the notation
%
%    T(i,j,k,l) 
%
% on the right hand side for sparse tensors.
%
% The arguments i,j must be scalars.
% The arguments k,l must be scalars or ':',':'.

if S.type == '()'
   i = S.subs{1};
   j = S.subs{2};
   k = S.subs{3};
   l = S.subs{4};
   
   if any([ndims(i) ndims(j) ndims(k) ndims(l)] ~= [2 2 2 2])
      error('Subsref for SparseTensor requires scalar (1-by-1) arguments');
   end
   if any([size(i);size(j);size(k);size(l)]~=ones(4,2)),
      error('Subsref for SparseTensor requires scalar (1-by-1) arguments');
   end
   
   if k==':' & l==':',
      a=reshape(T.mat(i+T.M*(j-1),:),T.M,T.N);
      return
   end
   
   if (i>T.M) | (i<1) | (k>T.M) | (k<1) | (j>T.N) | (j<1) | (l>T.N) | (l<1),
      error('In subsref for SparseTensor: Index out of range');
   end
   
   a=T.mat(i+T.M*(j-1),k+T.M*(l-1));
else
   error('Subsref for SparseTensor works only as T(i,j,k,l)');
end
