function AppendToFile(cg,fname,opt)
%
% AppendToFile - save specifications of computational grid in a mat-file.
%
% AppendToFile(cg,fname) will append variables Rmax, dr, dt, R, and T to the 
% mat-file fname.
%
% AppendToFile(cg,fid,opt) with opt.style=='ascii' will write out Rmax, dr, and 
% dt, to the ascii file with file id fname. (See fprintf)

if nargin==2,
	opt = [];   
end

if ~isfield(opt,'style')
   opt.style='mat';
end

Rmax = rmax(cg);
[M,N] = size(cg);
R = RR(cg);
T = TT(cg);
gamma = GetGamma(cg);

if strcmpi(opt.style,'mat')
   save(fname,'Rmax','M','N','R','T','gamma','-append')
   return
end

if strcmpi(opt.style,'ascii')
   fprintf(fname,'##############################################################\n');
   fprintf(fname,'THE COMPUTATIONAL GRID\n');
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Rmax:\t\t\t\t\t\t\t%6.2f\n',Rmax);
   fprintf(fname,'No. of radii:\t\t\t\t\t\t%6.2f\n',M);
   fprintf(fname,'Number of angles:\t\t\t\t\t%6.2f\n',N);
   fprintf(fname,'Angular scaling parameter (0: uniform, 1: extreme):\t%6.2f\n',gamma);
   fprintf(fname,'##############################################################\n');
   return
end

error('Error in AppendToFile: Unrecognized style field in option')