function CA = CellArea(cg)
%
% Return a matrix, the elements of each give the area of the
% cell surrounding that point.
%
% Since the grid is axisymmetric, we actually return 2 times this
% area.
%
% See also: loggrid

R = Rad(cg);
T = Ang(cg);
M = length(R);
N = length(T);

% Compute the inner and outer radii of the cell around each grid point
R = [R(1);R;R(M)];
R = ( R(1:(end-1)) + R(2:end) ) /2;

% Compute the angular width corresponding to each point in the grid
T = [-T(1),T,2*pi-T(end)];
dT = (T(3:end)-T(1:(end-2)))/2;

% Do not reduce with a factor two because we only look at half grids.
CA = ( R(2:end).^2 - R(1:M).^2) *dT;