function DiffOps=FourthOrderCentral(cg,options)
%
% DiffOps=FourthOrderCentral(cg)
%
% Returns discretized versions of d/dr, d/dtheta, d^2/dr^2 and d^2 /dtheta^2 
% corresponding to the logaritmic computaitonal grid cg.
%
% Employs a fourth order central finite difference scheme.
%
% This function will typically only be called from the constructor TensorMatrix
%
% See also: loggrid, unifgrid, compgrid, FlowField, TensorMatrix

if nargin==1,
   options = [];
end

% Extract grid positions from the grid
R = RR(cg);
T = TT(cg);

% Mesh size in the computational grid
h = logrstep(cg);
k = psistep(cg);

% Find number of radii and angles in the computational grid
[M,N] = size(cg);

% Find the corresponding rectangular grid.
rgr = rectgrid(M,N);

% Find the differential operators corresponding to this rectangular grid.
RecDiffOps = FourthOrderCentral(rgr,options);

% Scale because our mesh size is not 1-by-1

DiffOps.dr = RecDiffOps.dx * (1/ h);
DiffOps.dr2 = RecDiffOps.dx2 * (1/ h^2);

DiffOps.dth = RecDiffOps.dy * (1/ k);
DiffOps.dth2 = RecDiffOps.dy2 * (1/ k^2);

% Transfrom because the radius s logarithmically scaled.

DiffOps.dr2 = (1./R./R)*(DiffOps.dr2-DiffOps.dr);
DiffOps.dr =  (1./R)* DiffOps.dr;

% Transfrom because the angle is scaled.

DiffOps.dth2 = (1+GetGamma(cg)*cos(T)).^2 *DiffOps.dth2 - GetGamma(cg)*sin(T)*DiffOps.dth;
DiffOps.dth =  (1+GetGamma(cg)*cos(T))* DiffOps.dth;

return
