function lg1 = refine(lg,faktor,rm1)
%
% lg1 = refine(lg,f)
%
% returns a logarithmic grid lg1 which is a refined version of lg
%
% lg1 contains a factor f more points in each direction; i.e. a total of f^2
% more points.
%
% If lg1 must contain the points in lg, then f should be odd.
%
% The default value for f is 3.
%
% An additional argument can be supplied 
%
% lg1 = refine(lg,f,rmax)
% 
% In that case lg1 is also expanded so that rmax(lg1) >= rmax.

if nargin<2,
   faktor = 3;
end

M = GetRadNum(lg);
N = GetAngNum(lg);
rm = rmax(lg);

M1 = faktor*(M-1)+1;
N1 = faktor*N;

if nargin>2,
   M2 = (M1-1) * log(rm1) / log(rm) +1;
   M2 = ceil(M2);
   rm1 = exp((M2-1)/(M1-1)*log(rm));
   M1 = M2;
else
   rm1 = rm;
end

lg1 = compgrid(rm1,M1,N1,'Refined grid',GetGamma(lg));
