function AppendToFile(ff,fname,opt)
%
% AppendToFile - save specifications of flowfield in a mat-file.
%
% AppendToFile(ff,fname) will append matrices UR and UT to the 
% mat-file fname.
%
% AppendToFile(ff,fname,opt) with opt.style='ascii' will print 
% UR, UT, and the deformation off poles and equator to the 
% ascii-file with file id fname. (See also fprintf)

if nargin==2,
	opt = [];   
end

if ~isfield(opt,'style')
   opt.style='mat';
end

ur = UR(ff);
ut = UT(ff);

if strcmpi(opt.style,'mat')
   save(fname,'ur','ut','-append')
   return
end

if strcmpi(opt.style,'ascii')
	R = RR(ff);
   T = TT(ff);
   M = size(R,1);
   dM = max(1,round(M/10));
   
   fprintf(fname,'##############################################################\n');
   fprintf(fname,'THE FLOW FIELD\n');
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Upstream\n');
   fprintf(fname,'Radius\tUr\tDeformation\n');
   C = Val(deformation(ff));
   for i=1:dM:M
   	fprintf(fname,'%6.2f\t%6.2f\t%6.2f\n',R(i,end),ur(i,end),C(i,end));
   end
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Downstream\n');
   fprintf(fname,'Radius\tUr\tDeformation\n');
   for i=1:dM:M
   	fprintf(fname,'%6.2f\t%6.2f\t%6.2f\n',R(i,1),ur(i,1),C(i,1));
   end
   fprintf(fname,'--------------------------------------------------------------\n');
   fprintf(fname,'Off equator\n');
   fprintf(fname,'Radius\tUt\tUr\tDeformation\n');
   j=round((1+size(R,2))/2);
   for i=1:dM:M
   	fprintf(fname,'%6.2f\t%6.2f\t%6.2f\t%6.2f\n',R(i,j),ut(i,j),ur(i,j),C(i,j));
   end
   fprintf(fname,'##############################################################\n');
   return
end

error('Error in AppendToFile: Unrecognized style field in option')