function DiffOps=FourthOrderUpwind(ff,Peclet)
%
% DiffOps=FourthOrderUpwind(ff,Peclet)
%
% Returns discretized versions of d/dr, d/dtheta, d^2/dr^2 and d^2 /dtheta^2 
% corresponding to the flowfield ff.
%
% Employs a third/fourth order upwind finite difference scheme.
%
% This function will typically only be called from the constructor TensorMatrix
%
% See also: compgrid, FlowField, TensorMatrix

DO = FourthOrderSkewed(ff);

% Extract flow field
R = RR(ff);
ur = UR(ff);
ut = UT(ff);

% Combine A and B: Find signed angular cell Peclet number
% SCP = ut .* R * k *Peclet;
SCP = ut .* R *Peclet;
[lambda,clambda] = ConvexCoef(SCP);
DiffOps.dth	= clambda * DO.dthA  + lambda * DO.dthB;
DiffOps.dth2= clambda * DO.dth2A + lambda * DO.dth2B;

% Combine A and B: Find signed radial cell Peclet number
SCP = ur * Peclet;
% SCP = ur * h * Peclet;
[lambda,clambda] = ConvexCoef(SCP);
DiffOps.dr = clambda * DO.drA + lambda * DO.drB;
DiffOps.dr2 = clambda * DO.dr2A + lambda * DO.dr2B;

return

function [l,cl]=ConvexCoef(SCP)
% Takes a matrix of Signed Cell Peclet Numbers and 
% returns the corresponding coefficients for the 
% convex combination of upwind and downwind parts.


% Hard shift
l = sign(SCP)/2 + 0.5;

% Soft shift: Use a smooth combination of the two schemes.
% l = atan(SCP)/pi + 0.5;

cl = 1 - l;

return
