function ff1 = interp(ff,cg1,options)
%
% ff1 = interp(ff,cg1)
%
% Interpolates the flowfield ff at the grid cg1. The result is a flowfield 
% defined on the grid cg1.

if nargin<3,
   options = [];
end

method = 'spline';

if isa(options,'char')
   method = options;
end

if isfield(options,'method'),
   method = options.method;
end

[M,N] = size(ff);
   
urff = UR(ff);
utff = UT(ff);
vorff = vorticity(ff);
R = RR(ff);
T = TT(ff);
[M,N] = size(R);
R = [R(:,1),R,R(:,1)];
T = [zeros(M,1),T,pi*ones(M,1)];
urff = [urff(:,1),urff,urff(:,N)];
utff = [zeros(M,1),utff,zeros(M,1) ];
vorff = [zeros(M,1),vorff,zeros(M,1) ];

Rmax = R(M,1);

T1 = TT(cg1);
R1 = RR(cg1);

T2 = min(T1,max(T(:)));
T2 = max(T2,min(T(:)));

R2 = min(R1,max(R(:)));
R2 = max(R2,min(R(:)));

ur1 = interp2(T,R,urff,T2,R2,method);
ut1 = interp2(T,R,utff,T2,R2,method);
vor1 = interp2(T,R,vorff,T2,R2,method);

% THESE sentences should assume free flow outside the region where the flow has been calculated ...
% but it gives weird results.

OUB = R1 > Rmax;
IB = R1 <= Rmax;

ur1 = OUB.*cos(T1) + IB .* ur1;
ut1 = -OUB.*sin(T1) + IB .* ut1;
vor1 = IB.*ut1;

ff1 = flowfield(ur1,ut1,cg1,struct('vor',vor1));

return

figure(10)
subplot(221)
plot(ff1)
subplot(222)
plot(ff1,struct('object','ur'))
subplot(223)
plot(ff1,struct('object','ut'))
subplot(224)

return


