function plot(ff,option)
% 
% plot(ff,options)
%
% Makes plot of a flow field in the current axis.
%
% options can be omitted, or a structure with one or more of the following 
% fields present:
%
%   options.size :	'full' or 'half' (default).
%   options.object:	'flow field' (default), 'ur', 'ut', 'ux', 'uz', controls
% 							what exactly to plot.
%   options.style:   If the object is 'flow field' and the style is 'quiver',
%							then a quiver plot is produced. Otherwise the option is 
%							passed on to NumField/plot
%
% See also: flowfield, NumField/plot

%%%%%%%%%%%%%% Set default options whenever options are missing %%%%%%%%%%%

if nargin<2,
   option = [];
end

if ~isfield(option,'size')
   option.size='half';
end

if ~isfield(option,'object')
   option.object='flow field';
end

if ~isfield(option,'style')
   option.style='surf';
end

%%%%%%%%%%%%%% Make the plot %%%%%%%%%%%

if strcmpi(option.object,'Flow field') & strcmpi(option.style,'Quiver')
   X = XX(ff);
   Z = ZZ(ff);
   
   ux = UX(ff);
   uz = UZ(ff);
   
   if strcmpi(option.size,'full')
      X = [X, -fliplr(X), X(:,1)];
      Z = [Z, fliplr(Z), Z(:,1)];
      
      ux = [ux, -fliplr(ux), ux(:,1)];
      uz = [uz, fliplr(uz), uz(:,1)];
   end
   
   quiver(X,Z,ux,uz)
   hold on 
   plotcircle([],option.size)
   hold off
   
   axis equal
   return
end

%%%%%%%%%%%%% If we make it this far, then we want a plot of some scalar field %%%%%%%%%%%%

if strcmpi(option.object,'Flow field')
   C = sqrt(UR(ff).^2+UT(ff).^2);
   ZeroPole = 0;
end

if strcmpi(option.object,'ur')
   C = UR(ff);
   ZeroPole = 0;
end

if strcmpi(option.object,'ut')
   C = UT(ff);   
   ZeroPole = 1;
end

if strcmpi(option.object,'ux')
   C = UX(ff);
   ZeroPole = 1;
end

if strcmpi(option.object,'uz')
	C = UZ(ff);   
   ZeroPole = 0;
end

if strcmpi(option.object,'deformation')
   C = Val(deformation(ff));
   ZeroPole = 0;
end

if strcmpi(option.object,'vorticity')
   C = vorticity(ff);
   ZeroPole = 1;
end

plot(NumField(C,compgrid(ff),[],ZeroPole),option);

return

