function gr=rectgrid(Arg1,Arg2,Arg3)
%
% rectgrid - Computational grid class; uniform in rectangular coordinates
%
% This is the base computational grid for defining discretisations of 
% differential operators. It is simple to implement a discretisation 
% scheme on this grid, because it is rectangular and has mesh size 1.
%
% Constructor:
%
%		cg = rectgrid;
%		cg = rectgrid(options);
%		cg = rectgrid(M,N);
%		cg = rectgrid(M,N,name);
%
% When called as rectgrid(M,N), the two arguments must be scalar. 
% A rectangular M-by-N grid is created. 
%

Default = struct('M',10,'N',9,'Name','Unnamed rectangular grid');

if nargin>3,
   error('Wrong number of arguments for rectgrid. See ''help unifgrid''.');
end

if nargin==0,
   M=Default.M;
   N=Default.N;
   Name = Default.Name;
end

if nargin==2,
   M = Arg1;
   N = Arg2;
   Name = Default.Name;
end

if nargin==3,
   M = Arg1;
   N = Arg2;
   Name = Arg3;
end

if nargin==1,
   if ~isfield(Arg1,'M'),
      Arg1.M = Default.M;
   end
   
   if ~isfield(Arg1,'N'),
      Arg1.N = Default.N;
   end
   
   if ~isfield(Arg1,'Name'),
      Arg1.Name= Default.Name;
   end
   
   M = Arg1.M;
   N = Arg1.N;
   Name = Arg1.Name;
end

cg = compgrid(Name);

gr = struct('M',M,'N',N);

gr = class(gr,'rectgrid',cg);
