function plot(psi,Reynold,gr,options)
%
% plot(psi) - plot function for streamfunction class
%
% plot(psi,Re,gr,options) produces a contour plot in the current 
% axes of streamfunction psi, at Reynolds number Re, evaluated at
% the grid points specified by computational grid gr.
%
% The actual plot is generated by NumField/plot . If options are 
% present, they are passed on to this routine. (See NumField/plot
% for a list of recognized options).
%
% gr may be omitted as in plot(psi,Re) in which case the defualt 
% grid is chosen
%
% Reynold may be omitted in which case it is set to 1.
%
% See also: NumField, streamfct, compgrid

if nargin<4,
   options=[];
end

if nargin<3
   gr = compgrid;
end

if nargin<2,
   Reynold = 1;
end

PS = NumField(eval(psi,RR(gr),TT(gr),Reynold),gr);

plot(PS,options)

colorbar
hold on 
plotcircle([],'half')
hold off
title(getname(psi))
axis equal 

return
