function out=CheckScalar(sc,range,mustbeint)
% Check if a scalar is admissable
%
% Syntax: out=CheckScalar(sc,range,mustbeint)
%
% Return values:
% 
% 0: The argument was admissable
% 1: The argument was not a double
% 2: The argument was not a scalar
% 3: The argument was NaN, Inf
% 4: The argument was too small
% 5: The argument was too large
% 6: The argument was no integer
%
% In case the argument has several flaws (e.g.
% is too small and no integer) only one of the 
% errors will be reported.
% 
% Mustbeint can be omitted, which is equivalent
% to setting it to 0 ('false')
%
% range can be omitted, which is equivalent to 
% setting it to [-inf,inf]
%
% If no argument is supplied, then an error is 
% generated (to be used in a try-catch structure)

if nargin<2,
   range = [-inf,inf];
end

res = 0;

if ~isa(sc,'double'),
   res = 1;
elseif prod(size(sc))~=1,
   res = 2;
elseif isnan(sc),
   res = 3;
elseif isinf(sc),
   res = 3;
else
   res = 0;
end

if (~res) & (nargin>1),
   if range(1)>sc,
      res = 4;
   elseif range(2)<sc,
      res = 5;
   end
end

if (~res) & (nargin>2)
   if mustbeint & (sc~=round(sc))
      res = 6;
   end
end

if nargout>0,
   out = res;
elseif res
   switch res
   case 1
      error('The argument was not a double');
   case 2
      error('The argument was not a scalar');
   case 3
      error('The argument was not finite');
   case 4
      error(['The argument was too small; must be at least ',num2str(range(1))]);   
   case 5
      error(['The argument was too large; must be at most ',num2str(range(2))]);   
   case 6
      error('The argument was no integer');
   otherwise
      error('Something unpredicted happended in CheckScalar');
   end
end
