function j = nsgradfun(x,D2,pfo,Re,D,sTR2,cotT,R)
% NSGRADFUN - Navier-Stokes gradient function.
%
% Syntax: dfdx = nsgradfun(x,D2,pfo)
%
% This function returns the gradient (Jacobian) in the Navier-Stokes equations, 
% for speeding up the Newton iteration.

persistent jac
if ~isempty(jac)
   j = jac;
   return
end

% Recover grid size
[M,N] = size(D2);

D2mat = array(D2);

jac = sparse(1:(2*M*N),1:(2*M*N),ones(1,2*M*N),2*M*N,2*M*N,2*M*N);

% The linear part at interior points
jac = [D2mat,sparse(1:(M*N),1:(M*N),-ones(1,M*N),M*N,M*N,M*N); sparse([],[],[],M*N,M*N),D2mat];

% Dirichlet conditions on psi
% Left boundary of psi equation
bci = 1:M;
jac(bci,:) = sparse(1:M,bci,ones(1,M),M,M*N*2,M);
% Right boundary 
bci = (1:M)+M*N-M;
jac(bci,:) = sparse(1:M,bci,ones(1,M),M,M*N*2,M);
% Bottom boundary 
bci = (1:N)*M+1-M;
jac(bci,:) = sparse(1:N,bci,ones(1,N),N,M*N*2,N);
% Top boundary 
bci = (1:N)*M;
jac(bci,:) = sparse(1:N,bci,ones(1,N),N,M*N*2,N);

% Dirichlet conditions on D2psi, and Neumann condition on psi
% Bottom boundary - this is a Neumann condition on D.dr * psi
bci = M*N+(1:N)*M+1-M;
bcipsi = (1:N)*M+1-M;
bcipsi2 = (1:N)*M+2-M;
jac(bci,:) = sparse([1:N,1:N],[bcipsi,bcipsi2],[ones(1,N),-ones(1,N)],N,M*N*2,2*N);
% Left boundary of D2psi equation
bci = M*N+(1:M);
jac(bci,:) = sparse(1:M,bci,ones(1,M),M,M*N*2,M);
% Right boundary 
bci = (1:M)+2*M*N-M;
jac(bci,:) = sparse(1:M,bci,ones(1,M),M,M*N*2,M);
% Top boundary 
bci = M*N + (1:N)*M;
jac(bci,:) = sparse(1:N,bci,ones(1,N),N,M*N*2,N);

j = jac;

return
